Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Files ¶
type Files struct {
// Optional environment variable key to override
OverrideEnv string
// Optional fallback directory to check, if not in memory.
DirFallback string
// SlurpToMemory controls whether on first access the file is
// slurped into memory. It's intended for use with DirFallback.
SlurpToMemory bool
// Listable controls whether requests for the http file "/" return
// a directory of available files. Must be set to true for
// http.FileServer to correctly handle requests for index.html.
Listable bool
// contains filtered or unexported fields
}
type ZlibCompressedBase64 ¶
type ZlibCompressedBase64 string
ZlibCompressedBase64 is used to store a compressed file. Unlike ZlibCompressed, the string is base64 encoded, in standard base64 encoding.
Directories
¶
| Path | Synopsis |
|---|---|
|
The genfileembed command embeds resources into Go files, to eliminate run-time dependencies on files on the filesystem.
|
The genfileembed command embeds resources into Go files, to eliminate run-time dependencies on files on the filesystem. |
Click to show internal directories.
Click to hide internal directories.